# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representative_filter_name import RepresentativeFilterName

class TestRepresentativeFilterName(unittest.TestCase):
    """RepresentativeFilterName unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepresentativeFilterName:
        """Test RepresentativeFilterName
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepresentativeFilterName`
        """
        model = RepresentativeFilterName()
        if include_optional:
            return RepresentativeFilterName(
                eq = '',
                greater_than = '',
                greater_than_or_equal = '',
                var_in = [
                    ''
                    ],
                is_nil = True,
                less_than = '',
                less_than_or_equal = '',
                not_eq = ''
            )
        else:
            return RepresentativeFilterName(
        )
        """

    def testRepresentativeFilterName(self):
        """Test RepresentativeFilterName"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
