# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.ticket_relationships import TicketRelationships

class TestTicketRelationships(unittest.TestCase):
    """TicketRelationships unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TicketRelationships:
        """Test TicketRelationships
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TicketRelationships`
        """
        model = TicketRelationships()
        if include_optional:
            return TicketRelationships(
                representative = openapi_client.models.ticket_relationships_representative.ticket_relationships_representative(
                    data = [
                        openapi_client.models.ticket_relationships_representative_data_inner.ticket_relationships_representative_data_inner(
                            id = '', 
                            meta = { }, 
                            type = '', )
                        ], )
            )
        else:
            return TicketRelationships(
        )
        """

    def testTicketRelationships(self):
        """Test TicketRelationships"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
