# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.ticket_api import TicketApi


class TestTicketApi(unittest.TestCase):
    """TicketApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TicketApi()

    def tearDown(self) -> None:
        pass

    def test_tickets_get(self) -> None:
        """Test case for tickets_get

        """
        pass

    def test_tickets_id_get(self) -> None:
        """Test case for tickets_id_get

        """
        pass

    def test_tickets_id_patch(self) -> None:
        """Test case for tickets_id_patch

        """
        pass

    def test_tickets_post(self) -> None:
        """Test case for tickets_post

        """
        pass


if __name__ == '__main__':
    unittest.main()
