# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.tickets_id_patch_request_data import TicketsIdPatchRequestData

class TestTicketsIdPatchRequestData(unittest.TestCase):
    """TicketsIdPatchRequestData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TicketsIdPatchRequestData:
        """Test TicketsIdPatchRequestData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TicketsIdPatchRequestData`
        """
        model = TicketsIdPatchRequestData()
        if include_optional:
            return TicketsIdPatchRequestData(
                attributes = openapi_client.models._tickets__id__patch_request_data_attributes._tickets__id__patch_request_data_attributes(
                    representative_id = '', ),
                id = '',
                relationships = None,
                type = 'ticket'
            )
        else:
            return TicketsIdPatchRequestData(
                id = '',
        )
        """

    def testTicketsIdPatchRequestData(self):
        """Test TicketsIdPatchRequestData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
