# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representative_filter import RepresentativeFilter

class TestRepresentativeFilter(unittest.TestCase):
    """RepresentativeFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepresentativeFilter:
        """Test RepresentativeFilter
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepresentativeFilter`
        """
        model = RepresentativeFilter()
        if include_optional:
            return RepresentativeFilter(
                var_and = openapi_client.models.representative_filter.representative-filter(
                    and = openapi_client.models.representative_filter.representative-filter(
                        id = openapi_client.models.representative_filter_id.representative-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        name = openapi_client.models.representative_filter_name.representative-filter-name(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        not = , 
                        or = , 
                        tickets = openapi_client.models.ticket_filter.ticket-filter(
                            representative = , 
                            representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), 
                            subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), ), 
                    id = openapi_client.models.representative_filter_id.representative-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    name = openapi_client.models.representative_filter_name.representative-filter-name(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    not = , 
                    or = , 
                    tickets = openapi_client.models.ticket_filter.ticket-filter(), ),
                id = openapi_client.models.representative_filter_id.representative-filter-id(
                    eq = '', 
                    greater_than = '', 
                    greater_than_or_equal = '', 
                    in = [
                        ''
                        ], 
                    is_nil = True, 
                    less_than = '', 
                    less_than_or_equal = '', 
                    not_eq = '', ),
                name = openapi_client.models.representative_filter_name.representative-filter-name(
                    eq = '', 
                    greater_than = '', 
                    greater_than_or_equal = '', 
                    in = [
                        ''
                        ], 
                    is_nil = True, 
                    less_than = '', 
                    less_than_or_equal = '', 
                    not_eq = '', ),
                var_not = openapi_client.models.representative_filter.representative-filter(
                    and = openapi_client.models.representative_filter.representative-filter(
                        id = openapi_client.models.representative_filter_id.representative-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        name = openapi_client.models.representative_filter_name.representative-filter-name(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        or = , 
                        tickets = openapi_client.models.ticket_filter.ticket-filter(
                            representative = , 
                            representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), 
                            subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), ), 
                    id = openapi_client.models.representative_filter_id.representative-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    name = openapi_client.models.representative_filter_name.representative-filter-name(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    or = , 
                    tickets = openapi_client.models.ticket_filter.ticket-filter(), ),
                var_or = openapi_client.models.representative_filter.representative-filter(
                    and = openapi_client.models.representative_filter.representative-filter(
                        id = openapi_client.models.representative_filter_id.representative-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        name = openapi_client.models.representative_filter_name.representative-filter-name(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        not = , 
                        tickets = openapi_client.models.ticket_filter.ticket-filter(
                            representative = , 
                            representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), 
                            subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), ), 
                    id = openapi_client.models.representative_filter_id.representative-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    name = openapi_client.models.representative_filter_name.representative-filter-name(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    not = , 
                    tickets = openapi_client.models.ticket_filter.ticket-filter(), ),
                tickets = openapi_client.models.ticket_filter.ticket-filter(
                    and = openapi_client.models.ticket_filter.ticket-filter(
                        id = openapi_client.models.ticket_filter_id.ticket-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        not = , 
                        or = , 
                        representative = openapi_client.models.representative_filter.representative-filter(
                            name = openapi_client.models.representative_filter_name.representative-filter-name(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), 
                        representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), ), 
                    id = openapi_client.models.ticket_filter_id.ticket-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    not = , 
                    or = , 
                    representative = openapi_client.models.representative_filter.representative-filter(), 
                    representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), )
            )
        else:
            return RepresentativeFilter(
        )
        """

    def testRepresentativeFilter(self):
        """Test RepresentativeFilter"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
