# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representative import Representative

class TestRepresentative(unittest.TestCase):
    """Representative unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Representative:
        """Test Representative
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Representative`
        """
        model = Representative()
        if include_optional:
            return Representative(
                attributes = openapi_client.models.representative_attributes.representative_attributes(
                    name = '', ),
                id = '',
                relationships = openapi_client.models.representative_relationships.representative_relationships(
                    tickets = openapi_client.models.representative_relationships_tickets.representative_relationships_tickets(
                        data = [
                            openapi_client.models.representative_relationships_tickets_data_inner.representative_relationships_tickets_data_inner(
                                id = '', 
                                meta = { }, 
                                type = '', )
                            ], ), ),
                type = ''
            )
        else:
            return Representative(
                id = '',
                type = '',
        )
        """

    def testRepresentative(self):
        """Test Representative"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
